% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/enrichment_analysis.R
\docType{methods}
\name{enrichment_analysis}
\alias{enrichment_analysis}
\alias{enrichment}
\title{Enrichment analysis}
\usage{
enrichment_analysis(geneList, universe = NULL, method = "ORT",
  type = "KEGG", organism = "hsa", pvalueCutoff = 0.25,
  qvalueCutoff = 0.2, pAdjustMethod = "BH", minGSSize = 2,
  maxGSSize = 50, plotTitle = NULL, color = "#3f90f7")
}
\arguments{
\item{geneList}{A character vector or a ranked numeric vector(for GSEA) with names of geneid,
specifying the genelist to do enrichment analysis.}

\item{universe}{A character vector, specifying the backgound genelist, default is whole genome.}

\item{method}{One of "ORT"(Over-Representing Test), "GSEA"(Gene Set Enrichment Analysis), "DAVID",
"GOstats", and "HGT"(HyperGemetric test), or index from 1 to 5}

\item{type}{Geneset category for testing, KEGG(default).}

\item{organism}{A character, specifying organism, such as "hsa" or "Human"(default), and "mmu" or "Mouse"}

\item{pvalueCutoff}{Pvalue cutoff.}

\item{qvalueCutoff}{Qvalue cutoff.}

\item{pAdjustMethod}{One of "holm", "hochberg", "hommel", "bonferroni", "BH", "BY", "fdr", "none".}

\item{minGSSize}{Minimal size of each geneSet for testing.}

\item{maxGSSize}{Maximal size of each geneSet for analyzing.}

\item{plotTitle}{Same as 'title' in 'plot'.}

\item{color}{Color of points.}
}
\value{
A list, including two items, \code{gridPlot} and \code{enrichRes}. \code{gridPlot} is
a ggplot object, and \code{enrichRes} is a enrichResult instance.
}
\description{
Enrichment analysis
}
\examples{
data(geneList, package = "DOSE")
genes <- names(geneList)[1:100]
keggA = enrichment_analysis(genes, method = "HGT", type = "KEGG")
print(keggA$gridPlot)

}
\seealso{
\code{\link{enrich.GOstats}}

\code{\link{enrich.DAVID}}

\code{\link{enrich.GSE}}

\code{\link{enrich.ORT}}

\code{\link{enrich.HGT}}

\code{\link[DOSE]{enrichResult-class}}
}
\author{
Feizhen Wu
}
